@@ -4,12 +4,11 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 from argparse import ArgumentParser, HelpFormatter
 from logging import CRITICAL, DEBUG, ERROR, INFO, WARNING
-from os import listdir
 from os.path import exists, isdir, isfile
+from platform import system
 
-from .adapters import names as adapter_names
+from .common.plugins import scan as scan_plugins
 from .common.utils import TIMEOUT_DELAY
-from .target import available as available_targets
 
 
 # ref: https://stackoverflow.com/questions/12268602/sort-argparse-help-alphabetically
@@ -35,7 +34,6 @@ class CommonArgs:
     IGNORE = ("log-limit", "timeout")
 
     def __init__(self):
-        super().__init__()
         # log levels for console logging
         self._level_map = {
             "CRIT": CRITICAL,
@@ -93,8 +91,8 @@ class CommonArgs:
         self.launcher_grp.add_argument(
             "--platform",
             default="ffpuppet",
-            help="Platforms available: %s (default: %%(default)s)"
-            % ", ".join(available_targets()),
+            help="Installed Platforms (Targets): %s (default: %%(default)s)"
+            % ", ".join(sorted(scan_plugins("grizzly_targets"))),
         )
         self.launcher_grp.add_argument("-p", "--prefs", help="prefs.js file to use")
         self.launcher_grp.add_argument(
@@ -124,12 +122,12 @@ class CommonArgs:
             " and will be closed. Typically this should be a few seconds greater"
             " than the value used for `test-duration`." % (TIMEOUT_DELAY,),
         )
-        self.launcher_grp.add_argument(
-            "--valgrind", action="store_true", help="Use Valgrind (Linux only)"
-        )
-        self.launcher_grp.add_argument(
-            "--xvfb", action="store_true", help="Use Xvfb (Linux only)"
-        )
+        if system().startswith("Linux"):
+            self.launcher_grp.add_argument(
+                "--xvfb", action="store_true", help="Use Xvfb."
+            )
+        else:
+            self.parser.set_defaults(xvfb=False)
 
         self.reporter_grp = self.parser.add_argument_group("Reporter Arguments")
         self.reporter_grp.add_argument(
@@ -147,6 +145,24 @@ class CommonArgs:
             help="Override tool name used when reporting issues to FuzzManager",
         )
 
+        if system().startswith("Linux"):
+            dbg_group = self.launcher_grp.add_mutually_exclusive_group()
+            dbg_group.add_argument(
+                "--pernosco",
+                action="store_true",
+                help="Use rr. Trace intended to be used with Pernosco.",
+            )
+            dbg_group.add_argument("--rr", action="store_true", help="Use rr.")
+            dbg_group.add_argument(
+                "--valgrind", action="store_true", help="Use Valgrind."
+            )
+        else:
+            self.parser.set_defaults(
+                pernosco=False,
+                rr=False,
+                valgrind=False,
+            )
+
         self.parser.epilog = (
             "For addition help check out the wiki:"
             " https://github.com/MozillaSecurity/grizzly/wiki"
@@ -158,37 +174,32 @@ class CommonArgs:
         return args
 
     def sanity_check(self, args):
-        if hasattr(super(), "sanity_check"):
-            super().sanity_check(args)  # pylint: disable=no-member
+        targets = scan_plugins("grizzly_targets")
+        if not targets:
+            self.parser.error("No Platforms (Targets) are installed")
 
         if "binary" not in self._sanity_skip and not isfile(args.binary):
-            self.parser.error("file not found: %r" % args.binary)
+            self.parser.error("file not found: %r" % (args.binary,))
 
         # sanitize ignore list
         args.ignore = {arg.lower() for arg in args.ignore}
         for ignore in args.ignore:
             if ignore not in self.IGNORABLE:
-                self.parser.error("Unrecognized ignore value: %s" % ignore)
-
-        if "input" not in self._sanity_skip and args.input:
-            if not exists(args.input):
-                self.parser.error("%r does not exist" % args.input)
-            elif isdir(args.input) and not listdir(args.input):
-                self.parser.error("%r is empty" % args.input)
+                self.parser.error("Unrecognized ignore value %r" % (ignore,))
 
         # check log level
         log_level = self._level_map.get(args.log_level.upper(), None)
         if log_level is None:
-            self.parser.error("Invalid log-level %r" % args.log_level)
+            self.parser.error("Invalid log-level %r" % (args.log_level,))
         args.log_level = log_level
 
         if args.log_limit < 0:
             self.parser.error("--log-limit must be >= 0")
-        args.log_limit *= 1048576
+        args.log_limit *= 1_048_576
 
         if args.memory < 0:
-            self.parser.error("-m/--memory must be >= 0")
-        args.memory *= 1048576
+            self.parser.error("--memory must be >= 0")
+        args.memory *= 1_048_576
 
         if args.relaunch < 1:
             self.parser.error("--relaunch must be >= 1")
@@ -196,21 +207,21 @@ class CommonArgs:
         if args.extension:
             for ext in args.extension:
                 if not exists(ext):
-                    self.parser.error("%r does not exist" % ext)
+                    self.parser.error("%r does not exist" % (ext,))
                 if not isdir(ext) or (isfile(ext) and ext.endswith(".xpi")):
                     self.parser.error("Extension must be a folder or .xpi")
 
-        if args.platform.lower() not in set(available_targets()):
-            self.parser.error("Unsupported platform %r" % args.platform)
+        if args.platform not in targets:
+            self.parser.error("Platform %r not installed" % (args.platform,))
 
         if args.prefs and not isfile(args.prefs):
-            self.parser.error("-p/--prefs not found %r" % args.prefs)
+            self.parser.error("--prefs file not found")
 
         if args.time_limit is not None and args.time_limit < 1:
-            self.parser.error("--time-limit must be at least 1")
+            self.parser.error("--time-limit must be >= 1")
 
         if args.timeout is not None and args.timeout < 1:
-            self.parser.error("--timeout must be at least 1")
+            self.parser.error("--timeout must be >= 1")
 
         if "tool" not in self._sanity_skip:
             if args.tool is not None and not args.fuzzmanager:
@@ -220,10 +231,11 @@ class CommonArgs:
 class GrizzlyArgs(CommonArgs):
     def __init__(self):
         super().__init__()
-        self._adapters = sorted(adapter_names())
         self._sanity_skip.add("tool")
         self.parser.add_argument(
-            "adapter", help="Available adapters: %s" % ", ".join(self._adapters)
+            "adapter",
+            help="Installed Adapters: %s"
+            % ", ".join(sorted(scan_plugins("grizzly_adapters"))),
         )
         self.parser.add_argument(
             "--enable-profiling",
@@ -232,7 +244,7 @@ class GrizzlyArgs(CommonArgs):
             " status reporter while running Grizzly.",
         )
         self.parser.add_argument(
-            "-i", "--input", help="Test case or directory containing test cases"
+            "-i", "--input", help="Test case or directory containing test cases."
         )
         self.parser.add_argument(
             "--limit",
@@ -251,10 +263,14 @@ class GrizzlyArgs(CommonArgs):
         )
 
         self.launcher_grp.add_argument(
-            "--coverage", action="store_true", help="Enable coverage collection"
+            "--coverage", action="store_true", help="Enable coverage collection."
         )
         self.launcher_grp.add_argument(
-            "--rr", action="store_true", help="Use RR (Linux only)"
+            "--runtime",
+            type=int,
+            default=0,
+            help="Maximum runtime in seconds. Checked after each iteration."
+            " (default: 'no limit')",
         )
 
         self.reporter_grp.add_argument(
@@ -262,26 +278,24 @@ class GrizzlyArgs(CommonArgs):
             "--collect",
             type=int,
             default=1,
-            help="Maximum number of test cases to include in the report"
-            "(default: %(default)s)",
+            help="Maximum number of test cases to include in the report."
+            " (default: %(default)s)",
         )
         self.reporter_grp.add_argument(
             "--s3-fuzzmanager",
             action="store_true",
             help="Report large attachments (if any) to S3 and then the crash &"
-            " S3 link to FuzzManager",
+            " S3 link to FuzzManager.",
         )
 
     def sanity_check(self, args):
         super().sanity_check(args)
+        adapters = scan_plugins("grizzly_adapters")
+        if not adapters:
+            self.parser.error("No Adapters are installed")
 
-        if args.adapter.lower() not in self._adapters:
-            msg = ["Adapter %r does not exist." % args.adapter.lower()]
-            if self._adapters:
-                msg.append("Available adapters: %s" % ", ".join(self._adapters))
-            else:
-                msg.append("No adapters available.")
-            self.parser.error(" ".join(msg))
+        if args.adapter not in adapters:
+            self.parser.error("Adapter %r is not installed" % (args.adapter,))
 
         if args.collect < 1:
             self.parser.error("--collect must be greater than 0")
@@ -291,13 +305,16 @@ class GrizzlyArgs(CommonArgs):
                 "--fuzzmanager and --s3-fuzzmanager are mutually exclusive"
             )
 
+        if args.input and not exists(args.input):
+            self.parser.error("%r does not exist" % (args.input,))
+
         if args.limit < 0:
-            self.parser.error("--limit must be >= 0 (0 = no limit)")
+            self.parser.error("--limit must be >= 0")
+
+        if args.runtime < 0:
+            self.parser.error("--runtime must be >= 0")
 
         if args.tool is not None and not (args.fuzzmanager or args.s3_fuzzmanager):
             self.parser.error(
                 "--tool can only be given with --fuzzmanager/--s3-fuzzmanager"
             )
-
-        if args.rr and args.valgrind:
-            self.parser.error("'--rr' and '--valgrind' cannot be used together")
