@@ -3,7 +3,6 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-from .adapter import Adapter, AdapterError
 from .iomanager import IOManager, ServerMap
 from .reporter import (
     FilesystemReporter,
@@ -15,13 +14,12 @@ from .reporter import (
 from .runner import Runner, RunResult
 from .status import Status
 from .storage import TestCase, TestCaseLoadFailure, TestFile, TestFileExists
-from .utils import grz_tmp
+from .utils import configure_logging, grz_tmp
 
 __all__ = (
-    "Adapter",
-    "AdapterError",
     "FilesystemReporter",
     "FuzzManagerReporter",
+    "configure_logging",
     "grz_tmp",
     "IOManager",
     "Report",
