@@ -17,7 +17,7 @@ from re import DOTALL, VERBOSE
 from re import compile as re_compile
 from shutil import copyfile, copyfileobj, move, rmtree
 from tarfile import open as tar_open
-from tempfile import mkstemp
+from tempfile import TemporaryDirectory, mkstemp
 from time import strftime
 from zipfile import ZIP_DEFLATED, ZipFile
 
@@ -62,7 +62,7 @@ class Report:
     DEFAULT_MAJOR = "NO_STACK"
     DEFAULT_MINOR = "0"
     HANG_STACK_HEIGHT = 10
-    MAX_LOG_SIZE = 1048576  # 1MB
+    MAX_LOG_SIZE = 1_048_576  # 1MB
 
     __slots__ = (
         "_crash_info",
@@ -89,10 +89,9 @@ class Report:
         if size_limit < 1:
             LOG.warning("No limit set on report log size!")
         else:
-            with scandir(path=log_path) as contents:
-                for log in contents:
-                    if log.is_file() and log.stat().st_size > size_limit:
-                        Report.tail(log.path, size_limit)
+            for log in scandir(path=log_path):
+                if log.is_file() and log.stat().st_size > size_limit:
+                    Report.tail(log.path, size_limit)
         # look through logs one by one until we find a stack
         for log_file in (x for x in self._logs if x is not None):
             with open(log_file, "rb") as log_fp:
@@ -283,18 +282,20 @@ class Report:
         prioritize_tokens = (
             "use-after-",
             "-buffer-overflow on",
+            ": data race ",
             ": SEGV on ",
             "access-violation on ",
             "attempting free on ",
             "negative-size-param",
             "-param-overlap",
         )
+        fallback = None
         found = None
         for fname in (x for x in logs if "asan" in x):
             with open(fname, "r") as log_fp:
                 data = log_fp.read(65536)
             # look for interesting crash info in the log
-            if "==ERROR:" in data:
+            if "==ERROR:" in data or "WARNING:" in data:
                 # check for e10s forced crash
                 if re_e10s_forced.search(data) is not None:
                     continue
@@ -310,8 +311,8 @@ class Report:
                     found = fname
                 # catch all (choose the one with info for now)
                 elif data:
-                    found = fname
-        return found
+                    fallback = fname
+        return found or fallback
 
     @staticmethod
     def _find_valgrind(logs):
@@ -381,11 +382,9 @@ class Report:
         Returns:
             LogMap: A LogMap pointing to log files or None if path is empty.
         """
-        to_scan = None
-        with scandir(path=path) as contents:
-            files = (x for x in contents if x.is_file())
-            # order by date hopefully the oldest log is the cause of the issue
-            to_scan = [x.path for x in sorted(files, key=lambda x: x.stat().st_mtime)]
+        files = (x for x in scandir(path=path) if x.is_file())
+        # order by date hopefully the oldest log is the cause of the issue
+        to_scan = [x.path for x in sorted(files, key=lambda x: x.stat().st_mtime)]
         if not to_scan:
             LOG.warning("No files found in %r", path)
             return None
@@ -493,8 +492,7 @@ class FilesystemReporter(Reporter):
             dest_path = pathjoin(self.report_path, report.major[:16])
         else:
             dest_path = self.report_path
-        if not isdir(dest_path):
-            makedirs(dest_path)
+        makedirs(dest_path, exist_ok=True)
         # dump test cases and the contained files to working directory
         for test_number, test_case in enumerate(test_cases):
             dump_path = pathjoin(dest_path, "%s-%d" % (report.prefix, test_number))
@@ -596,14 +594,20 @@ class FuzzManagerReporter(Reporter):
     @staticmethod
     def _ignored(report):
         # This is here to prevent reporting stack-less crashes
-        # that were caused by system OOM or bogus other crashes
+        # that were caused by system OOM
         with open(report.preferred, "rb") as log_fp:
             log_data = log_fp.read().decode("utf-8", errors="ignore")
-        mem_errs = ("ERROR: Failed to mmap", ": AddressSanitizer failed to allocate")
         # ignore sanitizer OOMs missing stack
-        for msg in mem_errs:
-            if msg in log_data and "#0 " not in log_data:
-                return True
+        if report.stack is None:
+            mem_errs = (
+                "ERROR: Failed to mmap",
+                # NOTE: max_allocation_size_mb can trigger a similar message
+                ": AddressSanitizer failed to allocate",
+                "Sanitizer: internal allocator is out of memory trying to allocate",
+            )
+            for msg in mem_errs:
+                if msg in log_data:
+                    return True
         # ignore Valgrind crashes
         if log_data.startswith("VEX temporary storage exhausted."):
             return True
@@ -694,38 +698,33 @@ class FuzzManagerReporter(Reporter):
                 copyfile(screen_log, target_log)
                 Report.tail(target_log, 10240)  # limit to last 10K
 
-        # add results to a zip file
-        zip_name = "%s.zip" % (report.prefix,)
-        with ZipFile(zip_name, mode="w", compression=ZIP_DEFLATED) as zip_fp:
-            # add test files
-            for dir_name, _, dir_files in walk(report.path):
-                arc_path = relpath(dir_name, report.path)
-                for file_name in dir_files:
-                    zip_fp.write(
-                        pathjoin(dir_name, file_name),
-                        arcname=pathjoin(arc_path, file_name),
-                    )
-
-        # override tool name if specified
-        if self.tool is not None:
-            collector.tool = self.tool
-
-        # announce shortDescription if crash is not in a bucket
-        if (
-            cache_metadata["_grizzly_seen_count"] == 1
-            and not cache_metadata["frequent"]
-        ):
-            LOG.info("Submitting new crash %r", cache_metadata["shortDescription"])
-        # submit results to the FuzzManager server
-        new_entry = collector.submit(
-            report.crash_info, testCase=zip_name, testCaseQuality=self.quality
-        )
+        with TemporaryDirectory(prefix="fm-zip", dir=grz_tmp()) as tmp_dir:
+            # add results to a zip file
+            zip_name = pathjoin(tmp_dir, "%s.zip" % (report.prefix,))
+            with ZipFile(zip_name, mode="w", compression=ZIP_DEFLATED) as zip_fp:
+                # add test files
+                for dir_name, _, dir_files in walk(report.path):
+                    arc_path = relpath(dir_name, report.path)
+                    for file_name in dir_files:
+                        zip_fp.write(
+                            pathjoin(dir_name, file_name),
+                            arcname=pathjoin(arc_path, file_name),
+                        )
+            # override tool name if specified
+            if self.tool is not None:
+                collector.tool = self.tool
+            # announce shortDescription if crash is not in a bucket
+            if (
+                cache_metadata["_grizzly_seen_count"] == 1
+                and not cache_metadata["frequent"]
+            ):
+                LOG.info("Submitting new crash %r", cache_metadata["shortDescription"])
+            # submit results to the FuzzManager server
+            new_entry = collector.submit(
+                report.crash_info, testCase=zip_name, testCaseQuality=self.quality
+            )
         LOG.info("Logged %d with quality %d", new_entry["id"], self.quality)
 
-        # remove zipfile
-        if isfile(zip_name):
-            unlink(zip_name)
-
         return new_entry["id"]
 
 
