@@ -8,6 +8,7 @@ from tempfile import mkdtemp
 from time import sleep, time
 
 from sapphire import SERVED_TIMEOUT
+
 from ..target import TargetLaunchError, TargetLaunchTimeout
 from .utils import grz_tmp
 
@@ -17,13 +18,16 @@ __credits__ = ["Tyson Smith"]
 
 LOG = getLogger(__name__)
 
-# _IdleChecker is used to help determine if the target is hung (actively using CPU)
-# or if it has not made expected the HTTP requests for other reasons (idle).
-# This will allow the framework to move on without interrupting execution of
-# long running test cases.
-# This is not perfect! It is to be used AFTER the test case timeout
-# (initial_delay) has elapsed.
+
 class _IdleChecker:
+    """_IdleChecker is used to help determine if the target is hung (actively using CPU)
+    or if it has not made expected the HTTP requests for other reasons (idle).
+    This will allow the framework to move on without interrupting execution of long
+    running test cases.
+    This is not perfect! It is to be used AFTER the test case timeout (initial_delay)
+    has elapsed.
+    """
+
     __slots__ = ("_check_cb", "_init_delay", "_poll_delay", "_threshold", "_next_poll")
 
     def __init__(self, check_cb, threshold, initial_delay, poll_delay=1):
@@ -74,9 +78,18 @@ class _IdleChecker:
 
 
 class Runner:
-    __slots__ = ("_close_delay", "_idle", "_relaunch", "_server", "_target", "_tests_run")
+    __slots__ = (
+        "_close_delay",
+        "_idle",
+        "_relaunch",
+        "_server",
+        "_target",
+        "_tests_run",
+    )
 
-    def __init__(self, server, target, close_delay=30, idle_threshold=0, idle_delay=0, relaunch=1):
+    def __init__(
+        self, server, target, close_delay=30, idle_threshold=0, idle_delay=0, relaunch=1
+    ):
         self._close_delay = close_delay
         if idle_threshold > 0:
             assert idle_delay > 0
@@ -97,7 +110,7 @@ class Runner:
         Args:
             location (str): URL to open via Target.
             env_mod (dict): Environment modifications.
-            max_retries (int): Number of retries to preform before re-raising
+            max_retries (int): Number of retries to perform before re-raising
                                TargetLaunchTimeout.
             retry_delay (int): Time in seconds to wait between retries.
 
@@ -134,14 +147,14 @@ class Runner:
         self._tests_run = 0
 
     @staticmethod
-    def location(srv_path, srv_port, close_after=None, timeout=None):
+    def location(srv_path, srv_port, close_after=None, time_limit=None):
         """Build a valid URL to pass to a browser.
 
         Args:
             srv_path (str): Path segment of the URL
             srv_port (int): Server listening port
             close_after (int): Harness argument.
-            timeout (int): Harness argument.
+            time_limit (int): Harness argument.
 
         Returns:
             str: A valid URL.
@@ -152,14 +165,22 @@ class Runner:
         if close_after is not None:
             assert close_after >= 0
             args.append("close_after=%d" % (close_after,))
-        if timeout is not None:
-            assert timeout >= 0
-            args.append("timeout=%d" % (timeout * 1000,))
+        if time_limit is not None:
+            assert time_limit >= 0
+            args.append("time_limit=%d" % (time_limit * 1000,))
         if args:
             return "?".join([location, "&".join(args)])
         return location
 
-    def run(self, ignore, server_map, testcase, test_path=None, coverage=False, wait_for_callback=False):
+    def run(
+        self,
+        ignore,
+        server_map,
+        testcase,
+        test_path=None,
+        coverage=False,
+        wait_for_callback=False,
+    ):
         """Serve a testcase and monitor the target for results.
 
         Args:
@@ -194,7 +215,8 @@ class Runner:
                 continue_cb=self._keep_waiting,
                 forever=wait_for_callback,
                 optional_files=tuple(testcase.optional),
-                server_map=server_map)
+                server_map=server_map,
+            )
             duration = time() - serve_start
         finally:
             # remove temporary files
@@ -207,6 +229,11 @@ class Runner:
         # add all include files that were served
         for url, resource in server_map.include.items():
             testcase.add_batch(resource.target, result.served, prefix=url)
+        if result.timeout:
+            LOG.debug("timeout detected")
+            if self._target.handle_hang(ignore_idle=True) or "timeout" in ignore:
+                result.status = RunResult.IGNORED
+            server_map.dynamic.pop("grz_empty", None)
         if result.attempted:
             self._tests_run += 1
             if coverage and not result.timeout:
@@ -214,7 +241,7 @@ class Runner:
                 # to help catch any coverage related issues.
                 self._target.dump_coverage()
             # relaunch check
-            if self._tests_run >= self._relaunch:
+            if self._tests_run >= self._relaunch and not result.timeout:
                 assert self._tests_run == self._relaunch
                 server_map.dynamic.pop("grz_empty", None)
                 LOG.debug("relaunch/shutdown limit hit")
@@ -243,11 +270,12 @@ class Runner:
             LOG.debug("landing page %r not served!", testcase.landing_page)
             self._target.close()
         # detect failure
-        failure_detected = self._target.detect_failure(ignore, result.timeout)
-        if failure_detected == self._target.RESULT_FAILURE:
-            result.status = RunResult.FAILED
-        elif failure_detected == self._target.RESULT_IGNORED:
-            result.status = RunResult.IGNORED
+        if result.status is None:
+            failure_detected = self._target.detect_failure(ignore)
+            if failure_detected == self._target.RESULT_FAILURE:
+                result.status = RunResult.FAILED
+            elif failure_detected == self._target.RESULT_IGNORED:
+                result.status = RunResult.IGNORED
         return result
 
     def _keep_waiting(self):
@@ -267,15 +295,26 @@ class Runner:
 
 
 class RunResult:
+    """A RunResult holds result details from a call to Runner.run().
+
+    Attributes:
+        attempted (bool): Test landing page (entry point) was requested.
+        duration (float): Time spent waiting for test contents to be served.
+        initial (bool): Target was (re)launched prior to run attempt.
+        served (tuple(str)): Files that were served.
+        status (int): Result status of test.
+        timeout (bool): A timeout occurred waiting for test to complete.
+    """
+
     FAILED = 1
     IGNORED = 2
 
     __slots__ = ("attempted", "duration", "initial", "served", "status", "timeout")
 
     def __init__(self, served, duration, status=None, timeout=False):
-        self.attempted = False  # entry point/landing page was requested
+        self.attempted = False
         self.duration = duration
-        self.initial = False  # target was (re)launched prior to attempt
+        self.initial = False
         self.served = served
         self.status = status
         self.timeout = timeout
