@@ -16,8 +16,7 @@ from time import time
 from zipfile import BadZipfile, ZipFile
 from zlib import error as zlib_error
 
-from ..target import sanitizer_opts
-from .utils import grz_tmp
+from .utils import grz_tmp, sanitizer_opts
 
 __all__ = ("TestCase", "TestFile", "TestCaseLoadFailure", "TestFileExists")
 __author__ = "Tyson Smith"
@@ -540,6 +539,7 @@ class TestFile:
             raise TypeError("file_name is invalid %r" % (file_name,))
         # name including path relative to wwwroot
         self._file_name = normpath(file_name)
+        # pylint: disable=consider-using-with
         self._fp = SpooledTemporaryFile(
             dir=grz_tmp("storage"), max_size=self.CACHE_LIMIT, prefix="testfile_"
         )
