@@ -4,15 +4,15 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 # pylint: disable=protected-access
 
-from itertools import chain
 import json
-import re
 import os
+import re
 import zipfile
+from itertools import chain
 
 import pytest
 
-from .storage import TestCase, TestFile, TestCaseLoadFailure, TestFileExists
+from .storage import TestCase, TestCaseLoadFailure, TestFile, TestFileExists
 
 
 def test_testcase_01(tmp_path):
@@ -36,13 +36,16 @@ def test_testcase_01(tmp_path):
         assert not tcase.contains("no_file")
         assert not any(tcase.optional)
         tcase.dump(str(tmp_path))
-        assert not any(tmp_path.glob("*"))
+        assert not any(tmp_path.iterdir())
         tcase.dump(str(tmp_path), include_details=True)
         assert (tmp_path / "test_info.json").is_file()
 
+
 def test_testcase_02(tmp_path):
     """test TestCase with TestFiles"""
-    tcase = TestCase("land_page.html", "redirect.html", "test-adapter", input_fname="testinput.bin")
+    tcase = TestCase(
+        "land_page.html", "redirect.html", "test-adapter", input_fname="testinput.bin"
+    )
     try:
         in_file = tmp_path / "testfile1.bin"
         in_file.write_bytes(b"test_req")
@@ -73,6 +76,7 @@ def test_testcase_02(tmp_path):
     finally:
         tcase.cleanup()
 
+
 def test_testcase_03(tmp_path):
     """test TestCase.add_meta()"""
     with TestCase("land_page.html", "redirect.html", "test-adapter") as tcase:
@@ -86,6 +90,7 @@ def test_testcase_03(tmp_path):
         assert meta_file.is_file()
         assert meta_file.read_bytes() == meta_data
 
+
 def test_testcase_04(tmp_path):
     """test TestCase.add_environ_var() and TestCase.env_vars"""
     with TestCase("land_page.html", "redirect.html", "test-adapter") as tcase:
@@ -101,6 +106,7 @@ def test_testcase_04(tmp_path):
         assert data["env"]["TEST_ENV_VAR"] == "1"
         assert data["env"]["TEST_NONE"] is None
 
+
 def test_testcase_05():
     """test TestCase.purge_optional()"""
     with TestCase("land_page.html", "redirect.html", "test-adapter") as tcase:
@@ -125,6 +131,7 @@ def test_testcase_05():
         tcase.purge_optional(["testfile1.bin"])
         assert not any(tcase.optional)
 
+
 def test_testcase_06():
     """test TestCase.data_size"""
     with TestCase("land_page.html", "redirect.html", "test-adapter") as tcase:
@@ -136,8 +143,9 @@ def test_testcase_06():
         tcase.add_meta(TestFile.from_data("123", "meta.bin"))
         assert tcase.data_size == 6
 
+
 def test_testcase_07(tmp_path):
-    """test TestCase.load_single() using a directory fail cases"""
+    """test TestCase.load_single() using a directory - fail cases"""
     # missing test_info.json
     with pytest.raises(TestCaseLoadFailure, match="Missing 'test_info.json'"):
         TestCase.load_single(str(tmp_path), True)
@@ -147,10 +155,12 @@ def test_testcase_07(tmp_path):
         TestCase.load_single(str(tmp_path), True)
     # test_info.json missing 'target' entry
     (tmp_path / "test_info.json").write_bytes(b"{}")
-    with pytest.raises(TestCaseLoadFailure, match="'test_info.json' has invalid 'target' entry"):
+    with pytest.raises(
+        TestCaseLoadFailure, match="'test_info.json' has invalid 'target' entry"
+    ):
         TestCase.load_single(str(tmp_path), True)
     # build a test case
-    src_dir = (tmp_path / "src")
+    src_dir = tmp_path / "src"
     src_dir.mkdir()
     (src_dir / "prefs.js").touch()
     entry_point = src_dir / "target.bin"
@@ -160,27 +170,32 @@ def test_testcase_07(tmp_path):
         src.dump(str(src_dir), include_details=True)
     # bad 'target' entry in test_info.json
     entry_point.unlink()
-    with pytest.raises(TestCaseLoadFailure, match="Entry point 'target.bin' not found in"):
+    with pytest.raises(
+        TestCaseLoadFailure, match="Entry point 'target.bin' not found in"
+    ):
         TestCase.load_single(str(src_dir), True)
     # bad 'env' entry in test_info.json
     entry_point.touch()
     with TestCase("target.bin", None, "test-adapter") as src:
         src.add_environ_var("TEST_ENV_VAR", 100)
         src.dump(str(src_dir), include_details=True)
-    with pytest.raises(TestCaseLoadFailure, match="'env_data' contains invalid 'env' entries"):
+    with pytest.raises(
+        TestCaseLoadFailure, match="'env_data' contains invalid 'env' entries"
+    ):
         TestCase.load_single(str(src_dir), True)
 
+
 def test_testcase_08(tmp_path):
     """test TestCase.load_single() using a directory"""
     # build a valid test case
-    src_dir = (tmp_path / "src")
+    src_dir = tmp_path / "src"
     src_dir.mkdir()
     (src_dir / "prefs.js").touch()
     entry_point = src_dir / "target.bin"
     entry_point.touch()
     (src_dir / "optional.bin").touch()
     (src_dir / "x.bin").touch()
-    nested = (tmp_path / "src" / "nested")
+    nested = tmp_path / "src" / "nested"
     nested.mkdir()
     # overlap file name in different directories
     (nested / "x.bin").touch()
@@ -196,17 +211,20 @@ def test_testcase_08(tmp_path):
         assert "target.bin" in (x.file_name for x in dst._files.required)
         assert "optional.bin" in (x.file_name for x in dst._files.optional)
         assert "x.bin" in (x.file_name for x in dst._files.optional)
-        assert os.path.join("nested", "x.bin") in (x.file_name for x in dst._files.optional)
+        assert os.path.join("nested", "x.bin") in (
+            x.file_name for x in dst._files.optional
+        )
         assert dst.env_vars["TEST_ENV_VAR"] == "100"
         assert dst.timestamp > 0
 
+
 def test_testcase_09(tmp_path):
     """test TestCase.load_single() using a file"""
     # invalid entry_point specified
     with pytest.raises(TestCaseLoadFailure, match="Missing or invalid TestCase"):
         TestCase.load_single(str(tmp_path / "missing_file"), False)
     # valid test case
-    src_dir = (tmp_path / "src")
+    src_dir = tmp_path / "src"
     src_dir.mkdir()
     (src_dir / "prefs.js").touch()
     entry_point = src_dir / "target.bin"
@@ -226,7 +244,30 @@ def test_testcase_09(tmp_path):
         assert "target.bin" in (x.file_name for x in tcase._files.required)
         assert "optional.bin" in (x.file_name for x in tcase._files.optional)
 
+
 def test_testcase_10(tmp_path):
+    """test TestCase - dump, load and compare"""
+    with TestCase("a.html", "b.html", "adpt") as org:
+        # set non default values
+        org.duration = 1.23
+        org.env_vars = {"en1": "1", "en2": "2"}
+        org.hang = True
+        org.input_fname = "infile"
+        org.time_limit = 10
+        org.add_from_data("a", "a.html")
+        org.dump(str(tmp_path), include_details=True)
+        loaded = TestCase.load_single(str(tmp_path), False)
+        try:
+            for prop in TestCase.__slots__:
+                if prop.startswith("_") or prop == "redirect_page":
+                    continue
+                assert getattr(loaded, prop) == getattr(org, prop)
+            assert org._existing_paths == loaded._existing_paths
+        finally:
+            loaded.cleanup()
+
+
+def test_testcase_11(tmp_path):
     """test TestCase.load() - missing file and empty directory"""
     # missing file
     with pytest.raises(TestCaseLoadFailure, match="Invalid TestCase path"):
@@ -234,9 +275,10 @@ def test_testcase_10(tmp_path):
     # empty path
     assert not TestCase.load(str(tmp_path), True)
 
-def test_testcase_11(tmp_path):
+
+def test_testcase_12(tmp_path):
     """test TestCase.load() - single file"""
-    tfile = (tmp_path / "testcase.html")
+    tfile = tmp_path / "testcase.html"
     tfile.touch()
     testcases = TestCase.load(str(tfile), False)
     try:
@@ -244,7 +286,8 @@ def test_testcase_11(tmp_path):
     finally:
         map(lambda x: x.cleanup, testcases)
 
-def test_testcase_12(tmp_path):
+
+def test_testcase_13(tmp_path):
     """test TestCase.load() - single directory"""
     with TestCase("target.bin", None, "test-adapter") as src:
         src.add_from_data("test", "target.bin")
@@ -255,9 +298,10 @@ def test_testcase_12(tmp_path):
     finally:
         map(lambda x: x.cleanup, testcases)
 
-def test_testcase_13(tmp_path):
+
+def test_testcase_14(tmp_path):
     """test TestCase.load() - multiple directories"""
-    nested = (tmp_path / "nested")
+    nested = tmp_path / "nested"
     nested.mkdir()
     with TestCase("target.bin", None, "test-adapter") as src:
         src.add_from_data("test", "target.bin")
@@ -272,7 +316,8 @@ def test_testcase_13(tmp_path):
     # try loading testcases that are nested too deep
     assert not TestCase.load(str(tmp_path), False)
 
-def test_testcase_14(tmp_path):
+
+def test_testcase_15(tmp_path):
     """test TestCase.load() - archive"""
     archive = tmp_path / "testcase.zip"
     # bad archive
@@ -289,20 +334,24 @@ def test_testcase_14(tmp_path):
     (tmp_path / "log_dummy.txt").touch()
     (tmp_path / "not_a_tc").mkdir()
     (tmp_path / "not_a_tc" / "file.txt").touch()
-    with zipfile.ZipFile(str(archive), mode="w", compression=zipfile.ZIP_DEFLATED) as zfp:
+    with zipfile.ZipFile(
+        str(archive), mode="w", compression=zipfile.ZIP_DEFLATED
+    ) as zfp:
         for dir_name, _, dir_files in os.walk(str(tmp_path)):
             arc_path = os.path.relpath(dir_name, str(tmp_path))
             for file_name in dir_files:
                 zfp.write(
                     os.path.join(dir_name, file_name),
-                    arcname=os.path.join(arc_path, file_name))
+                    arcname=os.path.join(arc_path, file_name),
+                )
     testcases = TestCase.load(str(archive), True)
     try:
         assert len(tuple(testcases)) == 3
     finally:
         map(lambda x: x.cleanup, testcases)
 
-def test_testcase_15(tmp_path):
+
+def test_testcase_16(tmp_path):
     """test TestCase.load_environ()"""
     (tmp_path / "ubsan.supp").touch()
     (tmp_path / "other_file").touch()
@@ -319,16 +368,17 @@ def test_testcase_15(tmp_path):
         assert "b=2" in opts
         assert len(opts) == 3
 
-def test_testcase_16(tmp_path):
+
+def test_testcase_17(tmp_path):
     """test TestCase.add_batch()"""
-    include = (tmp_path / "inc_path")
+    include = tmp_path / "inc_path"
     include.mkdir()
-    inc_1 = (include / "file.bin")
+    inc_1 = include / "file.bin"
     inc_1.write_bytes(b"a")
     (include / "nested").mkdir()
-    inc_2 = (include / "nested" / "nested.js")
+    inc_2 = include / "nested" / "nested.js"
     inc_2.write_bytes(b"a")
-    other_path = (tmp_path / "other_path")
+    other_path = tmp_path / "other_path"
     other_path.mkdir()
     (other_path / "no_include.bin").write_bytes(b"a")
     with TestCase("a.b", "a.b", "simple") as tcase:
@@ -343,7 +393,10 @@ def test_testcase_16(tmp_path):
         tcase.add_batch(str(include), ["file.bin"])
         assert not tcase._existing_paths
         # valid list
-        tcase.add_batch(str(include), [str(inc_1), str(inc_2), str(tmp_path / "inc_path2" / "extra.bin")])
+        tcase.add_batch(
+            str(include),
+            [str(inc_1), str(inc_2), str(tmp_path / "inc_path2" / "extra.bin")],
+        )
         assert tcase.contains("file.bin")
         assert tcase.contains(os.path.join("nested", "nested.js"))
         assert len(tcase._existing_paths) == 2
@@ -355,11 +408,12 @@ def test_testcase_16(tmp_path):
         with pytest.raises(TestFileExists, match="'file.bin' exists in test"):
             tcase.add_batch(str(include), [str(inc_1)])
 
-def test_testcase_17(tmp_path):
+
+def test_testcase_18(tmp_path):
     """test TestCase.scan_path()"""
     # empty path
     (tmp_path / "not-test").mkdir()
-    assert not tuple(TestCase.scan_path(str(tmp_path)))
+    assert not any(TestCase.scan_path(str(tmp_path)))
     # multiple test case directories
     paths = [str(tmp_path / ("test-%d" % i)) for i in range(3)]
     with TestCase("test.htm", None, "test-adapter") as src:
@@ -372,16 +426,20 @@ def test_testcase_17(tmp_path):
     tc_paths = list(TestCase.scan_path(str(paths[0])))
     assert len(tc_paths) == 1
 
-def test_testcase_18():
+
+def test_testcase_19():
     """test TestCase.get_file()"""
     with TestCase("test.htm", None, "test-adapter") as src:
         src.add_from_data("test", "test.htm")
         assert src.get_file("missing") is None
         assert src.get_file("test.htm").data == b"test"
 
-def test_testcase_19():
+
+def test_testcase_20():
     """test TestCase.clone()"""
-    with TestCase("test.htm", "redirect.htm", "test-adaptor", "input.py") as src:
+    with TestCase("a.htm", "b.htm", "adpt", input_fname="fn", time_limit=2) as src:
+        src.duration = 1.2
+        src.hang = True
         src.add_from_data("123", "test.htm")
         src.add_from_data("456", "opt.htm", required=False)
         src.add_meta(TestFile.from_data("pref", "prefs.js"))
@@ -392,7 +450,11 @@ def test_testcase_19():
                     continue
                 assert getattr(src, prop) == getattr(tgt, prop)
             assert src.data_size == tgt.data_size
-            for file, data in (("test.htm", b"123"), ("opt.htm", b"456"), ("prefs.js", b"pref")):
+            for file, data in (
+                ("test.htm", b"123"),
+                ("opt.htm", b"456"),
+                ("prefs.js", b"pref"),
+            ):
                 src.get_file(file).write(b"src")
                 tgt.get_file(file).write(b"tgt")
                 assert src.get_file(file).data == data + b"src"
@@ -402,6 +464,7 @@ def test_testcase_19():
             assert src.env_vars == {"foo": "bar", "go": "away"}
             assert tgt.env_vars == {"hello": "kitty", "go": "away"}
 
+
 def test_testfile_01():
     """test simple TestFile"""
     with TestFile("test_file.txt") as tfile:
@@ -411,6 +474,7 @@ def test_testfile_01():
         tfile.close()
         assert tfile._fp.closed
 
+
 def test_testfile_02():
     """test TestFile file names"""
     # empty file name
@@ -441,6 +505,7 @@ def test_testfile_02():
     with TestFile(".file") as tfile:
         assert tfile.file_name == ".file"
 
+
 def test_testfile_03(tmp_path):
     """test TestFile.write() and TestFile.dump()"""
     out_file = tmp_path / "test_file.txt"
@@ -454,6 +519,7 @@ def test_testfile_03(tmp_path):
         tfile.dump(str(tmp_path))
         assert out_file.read_text() == "foobar"
 
+
 def test_testfile_04(tmp_path):
     """test TestFile.dump() file with nested path"""
     file_path = "test/dir/path/file.txt"
@@ -464,6 +530,7 @@ def test_testfile_04(tmp_path):
         tfile.dump(str(tmp_path))
         assert out_file.is_file()
 
+
 def test_testfile_05(tmp_path):
     """test TestFile.from_data()"""
     # TODO: different encodings
@@ -473,6 +540,7 @@ def test_testfile_05(tmp_path):
         assert out_file.is_file()
         assert out_file.read_text() == "foo"
 
+
 def test_testfile_06(tmp_path):
     """test TestFile.from_file()"""
     in_file = tmp_path / "infile.txt"
@@ -488,6 +556,7 @@ def test_testfile_06(tmp_path):
         assert out_file.is_file()
         assert out_file.read_text() == "foobar"
 
+
 def test_testfile_07(tmp_path):
     """test TestFile.clone()"""
     out_file = tmp_path / "test_file.txt"
@@ -507,6 +576,7 @@ def test_testfile_07(tmp_path):
         assert out_file.is_file()
         assert out_file.read_text() == "foobar"
 
+
 def test_testfile_08(tmp_path):
     """test TestFile.data()"""
     in_file = tmp_path / "infile.txt"
