@@ -2,22 +2,22 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
-from logging import DEBUG, basicConfig, getLogger
-from os import getcwd, getenv, getpid
+from logging import DEBUG, getLogger
+from os import getcwd, getpid
 from os.path import join as pathjoin
 
 from sapphire import Sapphire
 
-from .adapters import get as get_adapter
+from .adapter import Adapter
+from .common.plugins import load as load_plugin
 from .common.reporter import (
     FilesystemReporter,
     FuzzManagerReporter,
     S3FuzzManagerReporter,
 )
-from .common.utils import TIMEOUT_DELAY
+from .common.utils import TIMEOUT_DELAY, configure_logging
 from .session import Session
-from .target import TargetLaunchError, TargetLaunchTimeout
-from .target import load as load_target
+from .target import Target, TargetLaunchError, TargetLaunchTimeout
 
 __author__ = "Tyson Smith"
 __credits__ = ["Tyson Smith", "Jesse Schwartzentruber"]
@@ -26,18 +26,6 @@ __credits__ = ["Tyson Smith", "Jesse Schwartzentruber"]
 LOG = getLogger(__name__)
 
 
-def configure_logging(log_level):
-    if getenv("DEBUG") == "1":
-        log_level = DEBUG
-    if log_level == DEBUG:
-        date_fmt = None
-        log_fmt = "%(asctime)s %(levelname).1s %(name)s | %(message)s"
-    else:
-        date_fmt = "%Y-%m-%d %H:%M:%S"
-        log_fmt = "[%(asctime)s] %(message)s"
-    basicConfig(format=log_fmt, datefmt=date_fmt, level=log_level)
-
-
 def main(args):
     configure_logging(args.log_level)
     LOG.info("Starting Grizzly (%d)", getpid())
@@ -50,7 +38,9 @@ def main(args):
         LOG.info("Ignoring: %s", ", ".join(args.ignore))
     if args.xvfb:
         LOG.info("Running with Xvfb")
-    if args.rr:
+    if args.pernosco:
+        LOG.info("Running with RR (Pernosco mode)")
+    elif args.rr:
         LOG.info("Running with RR")
     elif args.valgrind:
         LOG.info("Running with Valgrind. This will be SLOW!")
@@ -60,9 +50,9 @@ def main(args):
     target = None
     try:
         LOG.debug("initializing Adapter %r", args.adapter)
-        adapter = get_adapter(args.adapter)()
+        adapter = load_plugin(args.adapter, "grizzly_adapters", Adapter)(args.adapter)
 
-        # test time limit and timeout sanity checking
+        # test case time limit and timeout sanity checking
         if args.time_limit:
             time_limit = args.time_limit
         else:
@@ -88,13 +78,14 @@ def main(args):
         else:
             relaunch = args.relaunch
 
-        LOG.debug("initializing the Target")
-        target = load_target(args.platform)(
+        LOG.debug("initializing the Target %r", args.platform)
+        target = load_plugin(args.platform, "grizzly_targets", Target)(
             args.binary,
             args.extension,
             args.launch_timeout,
             args.log_limit,
             args.memory,
+            pernosco=args.pernosco,
             rr=args.rr,
             valgrind=args.valgrind,
             xvfb=args.xvfb,
@@ -117,8 +108,10 @@ def main(args):
             reporter = FilesystemReporter(pathjoin(getcwd(), "results"))
             LOG.info("Results will be stored in %r", reporter.report_path)
 
-        if args.limit > 0:
+        if args.limit:
             LOG.info("%r iteration(s) will be attempted", args.limit)
+        if args.runtime:
+            LOG.info("Runtime is limited to %rs", args.runtime)
 
         # set 'auto_close=1' so the client error pages (code 4XX) will
         # call 'window.close()' after a second.
@@ -146,6 +139,7 @@ def main(args):
                 time_limit,
                 input_path=args.input,
                 iteration_limit=args.limit,
+                runtime_limit=args.runtime,
                 display_mode=display_mode,
             )
 
