@@ -19,14 +19,13 @@ from FTB.Signatures.CrashInfo import CrashSignature
 from sapphire import Sapphire
 
 from ..common.fuzzmanager import CrashEntry
+from ..common.plugins import load as load_plugin
 from ..common.reporter import FilesystemReporter, FuzzManagerReporter
 from ..common.storage import TestCaseLoadFailure, TestFile
-from ..common.utils import ConfigError, grz_tmp
-from ..main import configure_logging
+from ..common.utils import ConfigError, configure_logging, grz_tmp
 from ..replay import ReplayManager
 from ..session import Session
-from ..target import TargetLaunchError, TargetLaunchTimeout
-from ..target import load as load_target
+from ..target import Target, TargetLaunchError, TargetLaunchTimeout
 from .exceptions import GrizzlyReduceBaseException, NotReproducible
 from .stats import ReductionStats
 from .strategies import STRATEGIES
@@ -713,10 +712,12 @@ class ReduceManager:
             LOG.info("Ignoring: %s", ", ".join(args.ignore))
         if args.xvfb:
             LOG.info("Running with Xvfb")
-        if args.valgrind:
-            LOG.info("Running with Valgrind. This will be SLOW!")
-        if args.rr:
+        if args.pernosco:
+            LOG.info("Running with RR (Pernosco mode)")
+        elif args.rr:
             LOG.info("Running with RR")
+        elif args.valgrind:
+            LOG.info("Running with Valgrind. This will be SLOW!")
 
         signature = None
         signature_desc = None
@@ -767,12 +768,13 @@ class ReduceManager:
             args.repeat = max(args.min_crashes, args.repeat)
             relaunch = min(args.relaunch, args.repeat)
             LOG.debug("initializing the Target")
-            target = load_target(args.platform)(
+            target = load_plugin(args.platform, "grizzly_targets", Target)(
                 args.binary,
                 args.extension,
                 args.launch_timeout,
                 args.log_limit,
                 args.memory,
+                pernosco=args.pernosco,
                 rr=args.rr,
                 valgrind=args.valgrind,
                 xvfb=args.xvfb,
@@ -844,7 +846,7 @@ class ReduceManager:
             LOG.error(exc.msg)
             return exc.code
 
-        except Exception:  # noqa pylint: disable=broad-except
+        except Exception:  # pylint: disable=broad-except
             LOG.exception("Exception during reduction!")
             return Session.EXIT_ERROR
 
