@@ -14,7 +14,7 @@ from pytest import raises
 from ..common import TestCaseLoadFailure
 from ..target import TargetLaunchError, TargetLaunchTimeout
 from . import ReduceManager
-from .args import ReduceArgs
+from .args import ReduceArgs, ReduceFuzzManagerIDArgs, ReduceFuzzManagerIDQualityArgs
 from .exceptions import GrizzlyReduceBaseException
 
 LOG = getLogger(__name__)
@@ -24,10 +24,10 @@ pytestmark = pytest.mark.usefixtures("tmp_path_fm_config")
 def test_args_01(capsys, tmp_path, mocker):
     """test args in common with grizzly.replay"""
     # pylint: disable=import-outside-toplevel
-    from ..replay.test_main import test_args_01 as real_test
+    from ..replay.test_args import test_replay_args_01 as real_test
 
-    mocker.patch("grizzly.replay.test_main.ReplayArgs", new=ReduceArgs)
-    real_test(capsys, tmp_path)
+    mocker.patch("grizzly.replay.test_args.ReplayArgs", new=ReduceArgs)
+    real_test(capsys, mocker, tmp_path)
 
 
 def test_args_02(tmp_path):
@@ -65,6 +65,24 @@ def test_args_02(tmp_path):
         ReduceArgs().parse_args([str(exe), str(inp), "--report-period", "15"])
 
 
+def test_args_03(tmp_path):
+    """test ReduceFuzzManagerIDArgs"""
+    exe = tmp_path / "binary"
+    exe.touch()
+    ReduceFuzzManagerIDArgs().parse_args([str(exe), "123"])
+
+
+def test_args_04(capsys, tmp_path):
+    """test ReduceFuzzManagerIDQualityArgs"""
+    exe = tmp_path / "binary"
+    exe.touch()
+    with raises(SystemExit):
+        ReduceFuzzManagerIDQualityArgs().parse_args(
+            [str(exe), "123", "--quality", "-1"]
+        )
+    assert "error: '--quality' value cannot be negative" in capsys.readouterr()[-1]
+
+
 @pytest.mark.parametrize(
     "patch_func, side_effect, return_value, kwargs, result",
     [
@@ -76,9 +94,9 @@ def test_args_02(tmp_path):
             1,
         ),
         ("grizzly.reduce.core.ReduceManager.run", TargetLaunchTimeout, None, {}, 1),
-        ("grizzly.reduce.core.load_target", KeyboardInterrupt, None, {}, 1),
+        ("grizzly.reduce.core.load_plugin", KeyboardInterrupt, None, {}, 1),
         (
-            "grizzly.reduce.core.load_target",
+            "grizzly.reduce.core.load_plugin",
             GrizzlyReduceBaseException(""),
             None,
             {},
@@ -109,7 +127,7 @@ def test_main_exit(mocker, patch_func, side_effect, return_value, kwargs, result
         QUAL_NO_TESTCASE=7,
         QUAL_REDUCER_ERROR=9,
     )
-    mocker.patch("grizzly.reduce.core.load_target", autospec=True)
+    mocker.patch("grizzly.reduce.core.load_plugin", autospec=True)
     mocker.patch("grizzly.reduce.core.Sapphire", autospec=True)
     # setup args
     args = mocker.Mock(
@@ -137,7 +155,7 @@ def test_main_exit(mocker, patch_func, side_effect, return_value, kwargs, result
 def test_main_launch_error(mocker, exc_type):
     mocker.patch("grizzly.reduce.core.FuzzManagerReporter", autospec=True)
     reporter = mocker.patch("grizzly.reduce.core.FilesystemReporter", autospec=True)
-    mocker.patch("grizzly.reduce.core.load_target", autospec=True)
+    mocker.patch("grizzly.reduce.core.load_plugin", autospec=True)
     mocker.patch("grizzly.reduce.core.ReplayManager.load_testcases")
     mocker.patch(
         "grizzly.reduce.core.ReplayManager.time_limits", return_value=(None, 10)
@@ -173,7 +191,7 @@ def test_main_launch_error(mocker, exc_type):
 def test_testcase_prefs(mocker, tmp_path, result):
     """test that prefs from testcase are used if --prefs not specified and --prefs
     overrides"""
-    load_target = mocker.patch("grizzly.reduce.core.load_target")
+    load_target = mocker.patch("grizzly.reduce.core.load_plugin")
     mocker.patch("grizzly.reduce.core.ReduceManager.run", autospec=True)
     mocker.patch("grizzly.reduce.core.Sapphire", autospec=True)
     rmtree_mock = mocker.patch("grizzly.reduce.core.rmtree", autospec=True)
