@@ -13,15 +13,14 @@ from FTB.Signatures.CrashInfo import CrashSignature
 
 from sapphire import Sapphire, ServerMap
 
+from ..common.plugins import load as load_plugin
 from ..common.reporter import FilesystemReporter, FuzzManagerReporter, Report
 from ..common.runner import Runner, RunResult
 from ..common.status import Status
 from ..common.storage import TestCase, TestCaseLoadFailure, TestFile
-from ..common.utils import TIMEOUT_DELAY, ConfigError, grz_tmp
-from ..main import configure_logging
+from ..common.utils import TIMEOUT_DELAY, ConfigError, configure_logging, grz_tmp
 from ..session import Session
-from ..target import TargetLaunchError, TargetLaunchTimeout
-from ..target import load as load_target
+from ..target import Target, TargetLaunchError, TargetLaunchTimeout
 
 __author__ = "Tyson Smith"
 __credits__ = ["Tyson Smith"]
@@ -505,7 +504,8 @@ class ReplayManager:
             # remove unpacked testcase data
             for tc_path in unpacked:
                 rmtree(tc_path)
-            self.target.close()
+            # we don't want to clean up but we are not checking results
+            self.target.close(force_close=True)
             # remove unprocessed reports
             for report in reports.values():
                 report.report.cleanup()
@@ -552,7 +552,9 @@ class ReplayManager:
             LOG.info("Ignoring: %s", ", ".join(args.ignore))
         if args.xvfb:
             LOG.info("Running with Xvfb")
-        if args.rr:
+        if args.pernosco:
+            LOG.info("Running with RR (Pernosco mode)")
+        elif args.rr:
             LOG.info("Running with RR")
         elif args.valgrind:
             LOG.info("Running with Valgrind. This will be SLOW!")
@@ -588,7 +590,11 @@ class ReplayManager:
             )
             LOG.info("Using time limit: %ds, timeout: %ds", time_limit, timeout)
             repeat = max(args.min_crashes, args.repeat)
-            relaunch = min(args.relaunch, repeat)
+            if args.no_harness:
+                LOG.debug("no-harness enabled, forcing relaunch=1")
+                relaunch = 1
+            else:
+                relaunch = min(args.relaunch, repeat)
             LOG.info(
                 "Repeat: %d, Minimum crashes: %d, Relaunch %d",
                 repeat,
@@ -596,12 +602,13 @@ class ReplayManager:
                 relaunch,
             )
             LOG.debug("initializing the Target")
-            target = load_target(args.platform)(
+            target = load_plugin(args.platform, "grizzly_targets", Target)(
                 args.binary,
                 args.extension,
                 args.launch_timeout,
                 args.log_limit,
                 args.memory,
+                pernosco=args.pernosco,
                 rr=args.rr,
                 valgrind=args.valgrind,
                 xvfb=args.xvfb,
