@@ -131,7 +131,7 @@ class Session:
 
     def generate_testcase(self, time_limit):
         LOG.debug("calling iomanager.create_testcase()")
-        test = self.iomanager.create_testcase(self.adapter.NAME, time_limit)
+        test = self.iomanager.create_testcase(self.adapter.name, time_limit)
         LOG.debug("calling self.adapter.generate()")
         with self.status.measure("generate"):
             self.adapter.generate(test, self.iomanager.server_map)
@@ -147,10 +147,12 @@ class Session:
         time_limit,
         input_path=None,
         iteration_limit=0,
+        runtime_limit=0,
         display_mode=DISPLAY_NORMAL,
     ):
-        assert time_limit > 0
         assert iteration_limit >= 0
+        assert runtime_limit >= 0
+        assert time_limit > 0
 
         LOG.debug("calling adapter.setup()")
         self.adapter.setup(input_path, self.iomanager.server_map)
@@ -274,6 +276,10 @@ class Session:
                 LOG.info("Hit iteration limit (%d)", iteration_limit)
                 break
 
+            if runtime_limit and self.status.runtime >= runtime_limit:
+                LOG.info("Hit runtime limit (%ds)", runtime_limit)
+                break
+
             # warn about large browser logs
             self.status.log_size = self.target.log_size()
             if self.status.log_size > self.TARGET_LOG_SIZE_WARN:
